@@ -1,5 +1,6 @@
 import subprocess
 from abc import ABC, abstractmethod
+import sys
 
 from instant_python.configuration.dependency.dependency_configuration import DependencyConfiguration
 
@@ -7,6 +8,7 @@ from instant_python.configuration.dependency.dependency_configuration import Dep
 class DependencyManager(ABC):
     def __init__(self, project_directory: str) -> None:
         self._project_directory = project_directory
+        self._system_os = sys.platform
 
     @abstractmethod
     def setup_environment(self, python_version: str, dependencies: list[DependencyConfiguration]) -> None:
